@@ -14,7 +14,12 @@ Usage::
 import sys
 from typing import Any, Dict, List
 
-from .literals import GroupConfigurationStatus, GroupFilterName, QueryErrorCode, QueryType
+from .literals import (
+    GroupConfigurationStatusType,
+    GroupFilterNameType,
+    QueryErrorCodeType,
+    QueryTypeType,
+)
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -170,7 +175,7 @@ GroupConfigurationTypeDef = TypedDict(
     {
         "Configuration": List["GroupConfigurationItemTypeDef"],
         "ProposedConfiguration": List["GroupConfigurationItemTypeDef"],
-        "Status": GroupConfigurationStatus,
+        "Status": GroupConfigurationStatusType,
         "FailureReason": str,
     },
     total=False,
@@ -179,7 +184,7 @@ GroupConfigurationTypeDef = TypedDict(
 GroupFilterTypeDef = TypedDict(
     "GroupFilterTypeDef",
     {
-        "Name": GroupFilterName,
+        "Name": GroupFilterNameType,
         "Values": List[str],
     },
 )
@@ -282,7 +287,7 @@ PendingResourceTypeDef = TypedDict(
 QueryErrorTypeDef = TypedDict(
     "QueryErrorTypeDef",
     {
-        "ErrorCode": QueryErrorCode,
+        "ErrorCode": QueryErrorCodeType,
         "Message": str,
     },
     total=False,
@@ -308,7 +313,7 @@ ResourceIdentifierTypeDef = TypedDict(
 ResourceQueryTypeDef = TypedDict(
     "ResourceQueryTypeDef",
     {
-        "Type": QueryType,
+        "Type": QueryTypeType,
         "Query": str,
     },
 )
